@@ -1,5 +1,5 @@
 /*  GNU Ocrad - Optical Character Recognition program
-    Copyright (C) 2003-2017 Antonio Diaz Diaz.
+    Copyright (C) 2003-2019 Antonio Diaz Diaz.
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -240,7 +240,7 @@ void Character::dprint( const Control & control, const Rectangle & charbox,
     if( gv[i].code == '\t' )
       std::fprintf( control.outfile, "guess '\\t', confidence %d    ",
                              gv[i].value );
-    else if( !control.utf8 )
+    else if( !control.utf8 || !gv[i].code )
       {
       unsigned char ch = UCS::map_to_byte( gv[i].code );
       if( ch ) std::fprintf( control.outfile, "guess '%c', confidence %d    ",
@@ -334,7 +334,7 @@ void Character::xprint( const Control & control ) const
                 left(), top(), width(), height(), guesses() );
 
   for( int i = 0; i < guesses(); ++i )
-    if( !control.utf8 )
+    if( !control.utf8 || !gv[i].code )
       {
       unsigned char ch = UCS::map_to_byte( gv[i].code );
       if( !ch ) ch = '_';
